@@ -9,12 +9,12 @@ class LightSensor(Thing):
     # regarding capabilities refer https://iot.mozilla.org/schemas
     # there is also another schema registry http://iotschema.org/docs/full.html not used by webthing
 
-    def __init__(self, gpio_number, description):
+    def __init__(self, gpio_number, name, description):
         Thing.__init__(
             self,
             'urn:dev:ops:illuminanceSensor-1',
-            'IlluminanceSensor',
-            ['OnOffSwitch'],
+            'Illuminance ' + name,
+            ['BinarySensor'],
             description
         )
 
@@ -24,10 +24,10 @@ class LightSensor(Thing):
                      'bright',
                      self.bright,
                      metadata={
-                         '@type': 'OnOffProperty',
+                         '@type': 'BooleanProperty',
                          'title': 'bright',
                          "type": "boolean",
-                         'description': 'Whether the lamp is bright',
+                         'description': 'Whether is bright',
                          'readOnly': True,
                      }))
 
@@ -49,9 +49,9 @@ class LightSensor(Thing):
         logging.info("is_bright: " + str(is_bright))
 
 
-def run_server(port, gpio_number, description):
-    light_sensor = LightSensor(gpio_number, description)
-    server = WebThingServer(SingleThing(light_sensor), port=port)
+def run_server(hostname:str, port: int, gpio_number: int, name: str, description: str):
+    light_sensor = LightSensor(gpio_number, name, description)
+    server = WebThingServer(SingleThing(light_sensor), hostname=hostname, port=port)
     try:
         logging.info('starting the server')
         server.start()
